| Title: | Packaged 'BCFtools' and 'HTSlib' Command-Line Tools |
|---|---|
| Description: | Builds and installs pinned 'bcftools' and 'htslib' command-line tools, including packaged plugins such as liftover and score. Provides executable discovery, deterministic plugin environment configuration, version inspection, and structured process execution. Variant table, 'DuckDB', 'DuckLake', Arrow, Parquet, and annotation APIs are intentionally owned by 'Rduckhts' rather than duplicated here. |
| Authors: | Sounkou Mahamane Toure [aut, cre], Abiomix FZ LLC [cph, fnd] (Copyright holder and funder of Abiomix contributions), Bonfield, James K and Marshall, John and Danecek, Petr and Li, Heng and Ohan, Valeriu and Whitwham, Andrew and Keane, Thomas Davies, Robert M, Pierre Lindenbaum [cph] (Authors of included htslib library and bcftools command line tools), Zilong Li [cph] (Author of the vcfpp library from whom makefiles and configure strategy is borrowed), Giulio Genovese [cph] (Author of BCFTools munge plugin) |
| Maintainer: | Sounkou Mahamane Toure <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.23-0.0.4.9000 |
| Built: | 2026-07-13 11:51:18 UTC |
| Source: | https://github.com/abiomix/abiomix-r-open |
Run the packaged bcftools executable
bcftools_run( args = character(), stdin = NULL, error_on_status = TRUE, echo = FALSE, timeout = Inf, env = character() )bcftools_run( args = character(), stdin = NULL, error_on_status = TRUE, echo = FALSE, timeout = Inf, env = character() )
args |
A character vector passed directly to the executable. |
stdin |
Optional standard input accepted by |
error_on_status |
Whether a non-zero exit status raises an error. |
echo |
Whether to echo child output while the process runs. |
timeout |
Process timeout in milliseconds; |
env |
Optional named environment overrides. |
A processx::run() result with status, stdout, and stderr.
Locate a packaged native executable
rbcftools_binary( tool = c("bcftools", "bgzip", "tabix", "htsfile", "annot-tsv", "ref-cache") ) bcftools_path() bgzip_path() tabix_path() htsfile_path() annot_tsv_path() ref_cache_path()rbcftools_binary( tool = c("bcftools", "bgzip", "tabix", "htsfile", "annot-tsv", "ref-cache") ) bcftools_path() bgzip_path() tabix_path() htsfile_path() annot_tsv_path() ref_cache_path()
tool |
One of |
The normalized absolute path to the executable.
Report the installed binary surface
rbcftools_capabilities()rbcftools_capabilities()
A list containing versions, executables, and bcftools plugins.
Locate packaged tool directories
bcftools_bin_dir() htslib_bin_dir() bcftools_plugins_dir() htslib_plugins_dir()bcftools_bin_dir() htslib_bin_dir() bcftools_plugins_dir() htslib_plugins_dir()
The package path for the requested binary or plugin directory.
List packaged tools and plugins
bcftools_tools() htslib_tools() bcftools_plugins()bcftools_tools() htslib_tools() bcftools_plugins()
A character vector of installed names.
Run a packaged native tool
rbcftools_run( tool, args = character(), stdin = NULL, error_on_status = TRUE, echo = FALSE, timeout = Inf, env = character() )rbcftools_run( tool, args = character(), stdin = NULL, error_on_status = TRUE, echo = FALSE, timeout = Inf, env = character() )
tool |
One of the names accepted by |
args |
A character vector passed directly to the executable. |
stdin |
Optional standard input accepted by |
error_on_status |
Whether a non-zero exit status raises an error. |
echo |
Whether to echo child output while the process runs. |
timeout |
Process timeout in milliseconds; |
env |
Optional named environment overrides. |
A processx::run() result with status, stdout, and stderr.
Inspect packaged native-tool versions
rbcftools_versions() bcftools_version() htslib_version()rbcftools_versions() bcftools_version() htslib_version()
rbcftools_versions() returns a named character vector.
bcftools_version() and htslib_version() return one version string.
Child processes launched by rbcftools_run() receive these values without
mutating the R process. Call this function only when another launcher needs
the variables in the current environment.
setup_hts_env()setup_hts_env()
Invisibly, the previous named values of HTS_PATH and
BCFTOOLS_PLUGINS.